useIsolatedController property

bool useIsolatedController
final

useIsolatedController can be useful if you need to use the same controller type for many widgets but the controller instances must be different. In this case pass an instance of the controller and set useIsolatedController to true. If it's set to true but a controller is not provided, you will get an exception. IMPORTANT: it it's set to true, then the controller is not available via findController and cannot be disposed of manually. It's completely bound to the instance of LiteState

Implementation

final bool useIsolatedController;