lite_repo library
Classes
Functions
-
initJsonDecoders(
Map< Type, ModelDecoderFunction> value) → void - Initializes JSON decoders for custom types so they can be easily restored from storage. Call this at the beginning of your app, just before you initialize LiteState controllers.
Typedefs
- ModelDecoderFunction = LSJsonEncodable Function(Map json)