lite_state library
Classes
- LiteRepo
-
LiteState<
T extends LiteStateController> -
LiteStateController<
T> - LSJsonEncodable
Functions
-
disposeControllerByType(
Type controllerType) → void -
fc<
T extends LiteStateController> () → T - fc - short for Find Controller
-
findController<
T extends LiteStateController> () → T -
initControllers(
Map< Type, ControllerInitializer> controllerInitializers) → void -
initControllersLazy(
Map< Type, ControllerInitializer> controllerInitializers) → void -
initJsonDecoders(
Map< Type, ModelDecoderFunction> value) → void - Initializes JSON decoders for custom types so they can be easily restored from storage. Call this at the beginning of your app, just before you initialize LiteState controllers.
-
onPostframe(
VoidCallback callback) → void -
resetAllControllers(
{bool dispose = false}) → void - just calls a reset() method on all initialized controllers what this method should / should not do is up to you. Just write your own implementation if you need it
Typedefs
- ControllerInitializer = LiteStateController Function()
-
LiteStateBuilder<
T extends LiteStateController> = Widget Function(BuildContext context, T controller) - ModelDecoderFunction = LSJsonEncodable Function(Map json)